@@ -5,9 +5,9 @@ use speculate::speculate;
 speculate! {
     describe "get_pkg_version" {
         it "should return a name and version number" {
-            let res = get_pkg_version("cargo-cmd").unwrap();
-            expect!(res.name).to(be_equal_to("cargo-cmd"));
-            expect!(res.version).to(be_equal_to("0.3.1"));
+            let res = get_pkg_version("cargo-llvm-cov").unwrap();
+            expect!(res.name).to(be_equal_to("cargo-llvm-cov"));
+            expect!(res.version).to(be_equal_to("0.1.3"));
         }
 
         it "should return an error when a package is not found" {
@@ -19,4 +19,14 @@ speculate! {
             }
         }
     }
+
+    describe "run" {
+        context "cargo binary"  {
+            it "should execute successfully" {
+                // TODO replace with test crates.
+                let mut args: Vec<String> = vec!["cargo".to_owned(), "bin".to_owned(), "cargo-llvm-cov".to_owned(), "--help".to_owned()];
+                run(&mut args).unwrap();
+            }
+        }
+    }
 }
